@@ -18,11 +18,9 @@
 #
 #=============================================================================
 
-use 5.014_001;
+package Term::CLI::Argument  0.052002 {
 
-package Term::CLI::Argument  0.052001 {
-
-use Modern::Perl 1.20140107;
+use Term::CLI::PerlFeatures;
 use Moo 1.000001;
 
 use Term::CLI::L10N;
@@ -91,7 +89,7 @@ Term::CLI::Argument - generic parent class for arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.052001
+version 0.052002
 
 =head1 SYNOPSIS
 
