@@ -18,11 +18,9 @@
 #
 #=============================================================================
 
-use 5.014_001;
+package Term::CLI::Argument::Number::Float  0.052002 {
 
-package Term::CLI::Argument::Number::Float  0.052001 {
-
-use Modern::Perl 1.20140107;
+use Term::CLI::PerlFeatures;
 use Scalar::Util 1.38 qw( looks_like_number );
 
 use Moo 1.000001;
@@ -51,7 +49,7 @@ Term::CLI::Argument::Number::Float - class for floating point arguments in Term:
 
 =head1 VERSION
 
-version 0.052001
+version 0.052002
 
 =head1 SYNOPSIS
 
