@@ -18,11 +18,9 @@
 #
 #=============================================================================
 
-use 5.014_001;
+package Term::CLI::Command  0.052002 {
 
-package Term::CLI::Command  0.052001 {
-
-use Modern::Perl 1.20140107;
+use Term::CLI::PerlFeatures;
 use List::Util 1.38 qw( first min );
 use Getopt::Long 2.42 qw( GetOptionsFromArray );
 use Types::Standard 1.000005 qw(
@@ -328,7 +326,7 @@ Term::CLI::Command - Class for (sub-)commands in Term::CLI
 
 =head1 VERSION
 
-version 0.052001
+version 0.052002
 
 =head1 SYNOPSIS
 
