@@ -18,11 +18,9 @@
 #
 #=============================================================================
 
-use 5.014_001;
+package Term::CLI::Element  0.052002 {
 
-package Term::CLI::Element  0.052001 {
-
-use Modern::Perl 1.20140107;
+use Term::CLI::PerlFeatures;
 use Term::CLI::ReadLine;
 
 use Types::Standard 1.000005 qw( Str );
@@ -48,7 +46,7 @@ Term::CLI::Element - generic parent class for elements in Term::CLI
 
 =head1 VERSION
 
-version 0.052001
+version 0.052002
 
 =head1 SYNOPSIS
 
