@@ -15,11 +15,9 @@
 #
 #=============================================================================
 
-use 5.014_001;
+package Term::CLI::L10N::en  0.052002 {
 
-package Term::CLI::L10N::en  0.052001 {
-
-use Modern::Perl 1.20140107;
+use Term::CLI::PerlFeatures;
 
 use parent 0.228 qw( Term::CLI::L10N );
 
@@ -41,7 +39,7 @@ Term::CLI::L10N::en - English localizations for Term::CLI
 
 =head1 VERSION
 
-version 0.052001
+version 0.052002
 
 =head1 SYNOPSIS
 
