@@ -18,14 +18,14 @@
 #
 #=============================================================================
 
-use 5.014_001;
+package Term::CLI::ReadLine  0.052002 {
 
-package Term::CLI::ReadLine  0.052001 {
-
-use Modern::Perl 1.20140107;
+use Term::CLI::PerlFeatures;
 
 use Carp qw( confess );
 
+BEGIN { $::ENV{PERL_RL} = 'Gnu' }
+
 use parent 0.228 qw( Term::ReadLine );
 
 use namespace::clean 0.25;
@@ -80,7 +80,7 @@ Term::CLI::ReadLine - maintain a single Term::ReadLine object
 
 =head1 VERSION
 
-version 0.052001
+version 0.052002
 
 =head1 SYNOPSIS
 
