@@ -18,11 +18,9 @@
 #
 #=============================================================================
 
-use 5.014_001;
+package Term::CLI::Role::CommandSet  0.052002 {
 
-package Term::CLI::Role::CommandSet  0.052001 {
-
-use Modern::Perl 1.20140107;
+use Term::CLI::PerlFeatures;
 use Term::CLI::L10N;
 
 use Types::Standard 1.000005 qw(
@@ -174,7 +172,7 @@ Term::CLI::Role::CommandSet - Role for (sub-)commands in Term::CLI
 
 =head1 VERSION
 
-version 0.052001
+version 0.052002
 
 =head1 SYNOPSIS
 
